@@ -6,7 +6,7 @@ pub mod individual2msgpack;
 pub mod individual2turtle;
 pub mod json2individual;
 pub mod msgpack2individual;
-pub mod onto;
+pub mod onto_impl;
 pub mod onto_index;
 pub mod parser;
 pub mod resource;
